#' tidyUSDA: An Interface to USDA QuickStats Data with Mapping Capabilities.
#' 
#' A minimal toolset for gathering USDA Quick Stat data for analysis and visualization.
#' 
#' @docType package
#' @name tidyUSDA
"_PACKAGE"